pm4py.algo.discovery.batches package
====================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.batches.utils
   pm4py.algo.discovery.batches.variants

Submodules
----------

pm4py.algo.discovery.batches.algorithm module
---------------------------------------------

.. automodule:: pm4py.algo.discovery.batches.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.batches
   :members:
   :undoc-members:
   :show-inheritance:
